from distutils.core import setup

setup(
	name = 'strathxx',
	version = '1.0.0',
	py_modules = ['emp'],
	author = 'Troon',
	author_email = 'jayombagi@gmail.com',
	url = 'http://www.prewired.co.ke',
	description = 'Demo package for @iLabAfrica ISS',

)
